@@ -1,6 +1,6 @@
 # Default selections run by the software (can be changed by the user):
 
-FILEPATH = ""
+FILEPATH = "/Users/holly/Desktop/dotscanner-main/images/demo"
 # Path to the file or directory of files that should be used. The default value is an empty string: ""
 
 PROGRAM = "density"
@@ -58,6 +58,10 @@ SKIPS_ALLOWED = 1
 REMOVE_EDGE_FRAMES = True
 # Whether edge frames should be removed from a lifetime calculation
 
+LIFETIME_MIN_FOR_PLOT = 1
+# Minimum lifetime to mark a dot in the output figure. The default value is 1, so that all dots
+# with a lifetime of 1 or greater are plotted.
+
 ######################################
 ############ DOT SETTINGS ############
 ######################################
@@ -136,4 +140,4 @@ LIFETIME_OUTPUT_FILENAME = "lifetimes.txt"
 FIGURE_DIRECTORY_NAME = "figures/"
 # The directory name where figures are to be saved (only if SAVE_FIGURES = True).
 # The default is "figures/", but this can be changed if the user typically keeps a similarly
-# named folder in their file structure for something else.
+# named folder in their file structure for something else.
\ No newline at end of file
